InfoObject class

Common classes used across different OpenAPI versions.

Implementers

Constructors

InfoObject({required String title, required String version, String? description, String? termsOfService, ContactObject? contact, LicenseObject? license, Map<String, dynamic>? extensions})
Creates an InfoObject with the given parameters.
const
InfoObject.fromMap(Map map)
Creates an InfoObject from a map.
factory

Properties

contact → ContactObject?
The contact information for the API.
final
description → String?
The description of the API.
final
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
final
hashCode → int
The hash code for this object.
no setterinherited
license → LicenseObject?
The license information for the API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
termsOfService → String?
The terms of service URL.
final
title → String
The title of the API.
final
version → String
The version of the API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the InfoObject to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited