LicenseObject class

License information for the API.

Implementers

Constructors

LicenseObject({required String name, String? url, String? identifier})
Creates a LicenseObject with the given name and optional url.
const
LicenseObject.fromMap(Map map)
Creates a LicenseObject from a map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → String?
The SPDX license identifier.
final
name → String
The name of the license.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String?
The URL of the license.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the LicenseObject to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited