open_api_v2 library

Classes

DocumentV2<T extends Map<String, dynamic>>
OpenAPI 2.0 (Swagger) Document
ExternalDocumentationObjectV2
External documentation object representing additional external documentation.
HeaderObjectV2
Header object representing a single header in a response.
ItemsObjectV2
Items object representing the type of items in an array.
OperationObjectV2
Operation object representing a single API operation on a path.
ParameterObjectV2
Parameter object representing a single operation parameter.
PathItemObjectV2
Path item object representing the operations available on a single path.
ResponseObjectV2
Response object representing a single response from an API operation.
SchemaObjectV2
Schema object representing a data model in the API.
SecuritySchemeApiKeyV2
API key security scheme.
SecuritySchemeBasicV2
Basic authentication security scheme.
SecuritySchemeCustomV2
Custom/unknown security scheme for forward compatibility.
SecuritySchemeOAuth2AccessCodeV2
OAuth2 Authorization Code flow security scheme.
SecuritySchemeOAuth2ApplicationV2
OAuth2 Client Credentials (Application) flow security scheme.
SecuritySchemeOAuth2ImplicitV2
OAuth2 Implicit flow security scheme.
SecuritySchemeOAuth2PasswordV2
/ OAuth2 Password flow security scheme.
SecuritySchemeOAuth2V2
OAuth2 security scheme.
SecuritySchemeObjectV2
Represents a security scheme in the API.
TagObjectV2
Tag object representing a tag for API documentation control.
XmlObjectV2
XML object representing additional XML metadata.