SecuritySchemeBasicV2 class
Basic authentication security scheme.
- Inheritance
-
- Object
- OpenApiObject<
Map< String, dynamic> > - SecuritySchemeObjectV2
- SecuritySchemeBasicV2
Constructors
-
SecuritySchemeBasicV2({String? description, Map<
String, dynamic> ? extensions}) -
Creates a SecuritySchemeBasicV2 with an optional
description.
Properties
- description → String?
-
A description of the security scheme.
finalinherited
-
extensions
→ Map<
String, dynamic> ? -
Vendor-specific extension fields (
x-*) merged into the object.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of the security scheme.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Converts the SecuritySchemeObjectV2 to a map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited