SecuritySchemeCustomV2 class

Custom/unknown security scheme for forward compatibility.

Inheritance

Constructors

SecuritySchemeCustomV2({required String type, String? description, Map<String, dynamic> properties = const {}, Map<String, dynamic>? extensions})
Creates a SecuritySchemeCustomV2 with the given type, optional description, and additional properties.

Properties

description String?
A description of the security scheme.
finalinherited
extensions Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
properties Map<String, dynamic>
Additional properties defined by the scheme.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of the security scheme.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts the SecuritySchemeObjectV2 to a map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited