XmlObjectV2 class

XML object representing additional XML metadata.

Inheritance

Constructors

XmlObjectV2({String? name, String? namespace, String? prefix, bool? attribute, bool? wrapped, Map<String, dynamic>? extensions})
Creates an XmlObjectV2 with the given parameters.
XmlObjectV2.fromMap(Map map)
Creates an XmlObjectV2 from a map.
factory

Properties

attribute → bool?
Indicates whether the XML element is an attribute.
final
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the XML element.
final
namespace → String?
The namespace of the XML element.
final
prefix → String?
The prefix of the XML element.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wrapped → bool?
Indicates whether the XML element is wrapped in a container element.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited