ApiKeySecuritySchemeV3 class

API key security scheme representing an API key authentication scheme.

Inheritance

Constructors

ApiKeySecuritySchemeV3({required String name, required String in_, String? description})
Creates an ApiKeySecuritySchemeV3 with the given parameters.
ApiKeySecuritySchemeV3.fromMap(Map data)
Creates an ApiKeySecuritySchemeV3 from a map.
factory

Properties

description → String?
A description of the security scheme.
finalinherited
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
in_ → String
The location of the API key.
final
name → String
The name of the API key.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the security scheme.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited