EncodingObjectV3 class

Encoding object representing encoding information for a media type.

Constructors

EncodingObjectV3({String? contentType, Map<String, OpenApiObject<Map>>? headers, String? style, bool? explode, bool? allowReserved})
Creates an EncodingObjectV3 with the given parameters.
EncodingObjectV3.fromMap(Map data)
Creates an EncodingObjectV3 from a map.
factory

Properties

allowReserved → bool?
Whether reserved characters are allowed in the encoding.
final
contentType → String?
The content type of the encoding.
final
explode → bool?
Whether the encoding is exploded.
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, OpenApiObject<Map>>?
A map of headers for the encoding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → String?
The style of the encoding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the EncodingObjectV3 to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited