HttpSecuritySchemeV3 class

HTTP security scheme representing an HTTP authentication scheme.

Inheritance

Constructors

HttpSecuritySchemeV3({required String scheme, String? bearerFormat, String? description})
Creates a HttpSecuritySchemeV3 with the given parameters.
HttpSecuritySchemeV3.fromMap(Map data)
Creates a HttpSecuritySchemeV3 from a map.
factory

Properties

bearerFormat → String?
A hint to the client to identify how the bearer token is formatted.
final
description → String?
A description of the security scheme.
finalinherited
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme → String
The name of the HTTP authentication scheme.
final
type → String
The type of the security scheme.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited