ImplicitOAuthFlowV3 class

Implicit OAuth flow representing the implicit OAuth2 flow.

Inheritance

Constructors

ImplicitOAuthFlowV3({required String authorizationUrl, String? refreshUrl, required Map<String, String> scopes})
Creates an ImplicitOAuthFlowV3 with the given parameters.
ImplicitOAuthFlowV3.fromMap(Map data)
Creates an ImplicitOAuthFlowV3 from a map.
factory

Properties

authorizationUrl → String
The URL to obtain the authorization code.
final
hashCode → int
The hash code for this object.
no setterinherited
refreshUrl → String?
The URL to refresh the token.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → Map<String, String>
A map of scopes to descriptions.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Creates an OAuthFlowObjectV3 from a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited