OpenIdSecuritySchemeV3 class

OpenID Connect security scheme representing an OpenID Connect authentication scheme.

Inheritance

Constructors

OpenIdSecuritySchemeV3({required String openIdConnectUrl, String? description})
Creates an OpenIdSecuritySchemeV3 with the given parameters.
OpenIdSecuritySchemeV3.fromMap(Map data)
Creates an OpenIdSecuritySchemeV3 from a map.
factory

Properties

description → String?
A description of the security scheme.
finalinherited
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
openIdConnectUrl → String
The OpenID Connect URL to discover OAuth2 configuration values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
The type of the security scheme.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited