ParameterBaseObjectV3 class

Media type object representing a media type in a content object.

Inheritance
Implementers

Constructors

ParameterBaseObjectV3({String? description, bool? required, bool? deprecated, bool? allowEmptyValue, String? style, bool? explode, bool? allowReserved, Object? schema, Object? example, Map<String, OpenApiObject<Map>>? examples, Map<String, MediaTypeObjectV3>? content})
Creates a ParameterBaseObjectV3 with the given parameters.

Properties

allowEmptyValue → bool?
Whether the parameter allows empty values.
final
allowReserved → bool?
Whether the parameter allows reserved characters.
final
content → Map<String, MediaTypeObjectV3>?
A map of media types to their corresponding media type objects.
final
deprecated → bool?
Whether the parameter is deprecated.
final
description → String?
An optional description of the parameter.
final
example → Object?
An example of the parameter's potential value.
final
examples → Map<String, OpenApiObject<Map>>?
Examples of the parameter's potential values.
final
explode → bool?
Whether the parameter should be exploded.
final
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
required → bool?
Whether the parameter is required.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → Object?
The schema defining the type used for the parameter.
final
style → String?
The style of the parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeValue(Object value, {required String parameterName}) → String
Serializes a parameter value according to OpenAPI style/explode options.
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited