ParameterObjectV3 class

Parameter object representing a parameter in an operation.

Inheritance

Constructors

ParameterObjectV3({required String name, required String in_, String? description, bool? required, bool? deprecated, bool? allowEmptyValue, String? style, bool? explode, bool? allowReserved, Object? schema, Object? example, Map<String, OpenApiObject<Map>>? examples, Map<String, MediaTypeObjectV3>? content})
Creates a ParameterObjectV3 with the given parameters.
ParameterObjectV3.fromMap(Map map)
Creates a ParameterObjectV3 from a map.
factory

Properties

allowEmptyValue → bool?
Whether the parameter allows empty values.
finalinherited
allowReserved → bool?
Whether the parameter allows reserved characters.
finalinherited
content → Map<String, MediaTypeObjectV3>?
A map of media types to their corresponding media type objects.
finalinherited
deprecated → bool?
Whether the parameter is deprecated.
finalinherited
description → String?
An optional description of the parameter.
finalinherited
example → Object?
An example of the parameter's potential value.
finalinherited
examples → Map<String, OpenApiObject<Map>>?
Examples of the parameter's potential values.
finalinherited
explode → bool?
Whether the parameter should be exploded.
finalinherited
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
in_ → String
The location of the parameter.
final
name → String
The name of the parameter.
final
required → bool?
Whether the parameter is required.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → Object?
The schema defining the type used for the parameter.
finalinherited
style → String?
The style of the parameter.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeValue(Object value, {required String parameterName}) → String
Serializes a parameter value according to OpenAPI style/explode options.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited