PathItemObjectV3 class

Path item object representing a path in the OpenAPI document.

Inheritance
Implementers

Constructors

PathItemObjectV3({required Map<String, OperationObjectV3> operations, String? ref, String? summary, String? description, ExternalDocumentationObjectV3? externalDocs, List<OpenApiObject<Map>>? parameters, Map<String, dynamic>? extensions})
Creates a PathItemObjectV3 with the given parameters.
PathItemObjectV3.fromMap(Map map)
Creates a PathItemObjectV3 from a map.
factory

Properties

description → String?
A verbose explanation of the path item behavior.
final
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
externalDocs → ExternalDocumentationObjectV3?
Additional external documentation for the path item.
final
hashCode → int
The hash code for this object.
no setterinherited
operations → Map<String, OperationObjectV3>
A map of HTTP methods to their corresponding operation objects.
finalinherited
parameters → List<OpenApiObject<Map>>?
A list of parameters that are applicable for all the operations described under this path.
finalinherited
ref → String?
A reference to an external definition of the path item.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String?
A short summary of the path item.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited