SchemaObjectV3<E extends Object> class

Schema object representing a schema in the OpenAPI specification.

Inheritance
Implementers

Constructors

SchemaObjectV3({String? id, String? schema, String? title, String? description, OpenApiType? type, Object? defaultValue, num? multipleOf, num? maximum, bool? exclusiveMaximum, num? minimum, bool? exclusiveMinimum, int? maxLength, int? minLength, Pattern? pattern, Map<String, dynamic>? additionalProperties, int? maxItems, int? minItems, bool? uniqueItems, int? maxProperties, int? minProperties, List<String>? required, List? enumValues, Map<String, OpenApiObject<Map>>? properties, List<JsonSchema>? allOf, List<JsonSchema>? oneOf, List<JsonSchema>? anyOf, OpenApiObject<Map>? not, bool? nullable, DiscriminatorObjectV3? discriminator, bool? readOnly, bool? writeOnly, XMLObjectV3? xml, ExternalDocumentationObjectV3? externalDocs, Object? example, OpenApiObject<Map>? items, bool? deprecated, Map<String, dynamic>? extensions})
Creates a SchemaObjectV3 with the given parameters.
SchemaObjectV3.fromMap(Map data)
Creates a SchemaObjectV3 from a map.
factory

Properties

additionalItems → bool?
Indicates whether additional items are allowed in an array.
finalinherited
additionalProperties → Map<String, dynamic>?
A map of additional properties in an object.
finalinherited
allOf → List<JsonSchema>?
A list of schemas that must all be valid.
finalinherited
anyOf → List<JsonSchema>?
A list of schemas where at least one must be valid.
finalinherited
defaultValue → Object?
The default value for the schema.
finalinherited
definitions → Map<String, JsonSchema>?
A map of schema definitions.
finalinherited
dependencies → Map<String, dynamic>?
A map of dependencies for properties.
finalinherited
deprecated → bool?
Whether the schema is deprecated.
final
description → String?
The description of the schema.
finalinherited
discriminator → DiscriminatorObjectV3?
A discriminator object to aid in serialization, deserialization, and validation.
final
enumValues → List?
An enumeration of possible values.
finalinherited
example → Object?
An example of the schema's potential value.
final
exclusiveMaximum → bool?
Indicates whether the maximum value is exclusive.
finalinherited
exclusiveMinimum → bool?
Indicates whether the minimum value is exclusive.
finalinherited
extensions → Map<String, dynamic>?
Vendor-specific extension fields (x-*) merged into the object.
finalinherited
externalDocs → ExternalDocumentationObjectV3?
External documentation for the schema.
final
hasAdditionalProperties → bool
Indicates whether additional properties are allowed in an object.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier for the schema.
finalinherited
items → OpenApiObject<Map>?
The schema defining the type of items in an array.
finalinherited
maximum → num?
The maximum value of the number.
finalinherited
maxItems → int?
The maximum number of items in an array.
finalinherited
maxLength → int?
The maximum length of the string.
finalinherited
maxProperties → int?
The maximum number of properties in an object.
finalinherited
minimum → num?
The minimum value of the number.
finalinherited
minItems → int?
The minimum number of items in an array.
finalinherited
minLength → int?
The minimum length of the string.
finalinherited
minProperties → int?
The minimum number of properties in an object.
finalinherited
multipleOf → num?
A number that the value must be a multiple of.
finalinherited
not → OpenApiObject<Map>?
A schema that must not be valid.
finalinherited
nullable → bool?
Whether the schema allows null values.
final
oneOf → List<JsonSchema>?
A list of schemas where exactly one must be valid.
finalinherited
pattern → Pattern?
A regular expression pattern that the string must match.
finalinherited
patternProperties → Map<String, JsonSchema>?
A map of pattern property schemas.
finalinherited
properties → Map<String, OpenApiObject<Map>>?
A map of property schemas.
finalinherited
readOnly → bool?
Whether the schema is read-only.
final
ref → String?
A reference to an external definition of the schema.
finalinherited
required → List<String>?
A list of required properties in an object.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
The schema version.
finalinherited
title → String?
The title of the schema.
finalinherited
type → OpenApiType?
The type of the schema (e.g., "string", "number", "integer", "boolean", "array", "object").
finalinherited
uniqueItems → bool?
Indicates whether the items in an array must be unique.
finalinherited
writeOnly → bool?
Whether the schema is write-only.
final
xml → XMLObjectV3?
An XML object to represent XML metadata for the schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the JsonSchema to a JSON map.
inherited
toMap() → Map<String, dynamic>
Converts the OpenApiObject to a map.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited