XMLObjectV3 class

XML object to represent XML metadata for a schema.

Constructors

XMLObjectV3({String? name, String? namespace, String? prefix, bool? attribute, bool? wrapped})
Creates an XMLObjectV3 with the given parameters.
const

Properties

attribute → bool?
Indicates whether the XML element is an attribute.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the XML element or attribute.
final
namespace → String?
The namespace of the XML element or attribute.
final
prefix → String?
The prefix to be used for the XML element or attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wrapped → bool?
Indicates whether the XML element is wrapped in a container element.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the XMLObjectV3 to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited