MediaTypeObjectV3 class
Media type object representing a media type in a request or response.
- Inheritance
-
- Object
- OpenApiObject<
Map< String, dynamic> > - MediaTypeObjectV3
Constructors
-
MediaTypeObjectV3({OpenApiObject<
Map> ? schema, Object? example, Map<String, OpenApiObject< ? examples, Map<Map> >String, EncodingObjectV3> ? encoding, Map<String, dynamic> ? extensions}) - Creates a MediaTypeObjectV3 with the given parameters.
- MediaTypeObjectV3.fromMap(Map data)
-
Creates a MediaTypeObjectV3 from a map.
factory
Properties
-
encoding
→ Map<
String, EncodingObjectV3> ? -
A map of encoding objects for the media type.
final
- example → Object?
-
A single example for the media type.
final
-
examples
→ Map<
String, OpenApiObject< ?Map> > -
Examples of the media type.
final
-
extensions
→ Map<
String, dynamic> ? -
Vendor-specific extension fields (
x-*) merged into the object.finalinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schema
→ OpenApiObject<
Map> ? -
The schema defining the type used for the media type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Converts the MediaTypeObjectV3 to a map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited