OAuth2SecuritySchemeV3 class
OAuth2 security scheme representing an OAuth2 authentication scheme.
- Inheritance
-
- Object
- OpenApiObject<
Map< String, dynamic> > - SecuritySchemeObjectV3
- OAuth2SecuritySchemeV3
Constructors
-
OAuth2SecuritySchemeV3({required Map<
String, OAuthFlowObjectV3> flows, String? description}) - Creates an OAuth2SecuritySchemeV3 with the given parameters.
Properties
- description → String?
-
A description of the security scheme.
finalinherited
-
extensions
→ Map<
String, dynamic> ? -
Vendor-specific extension fields (
x-*) merged into the object.finalinherited -
flowList
→ List<
OAuthFlowObjectV3> -
Backward-compatible flattened view of OAuth2 flows.
no setter
-
flows
→ Map<
String, OAuthFlowObjectV3> -
OAuth2 flows keyed by flow name (implicit, password, clientCredentials, authorizationCode).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type of the security scheme.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Converts the OpenApiObject to a map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited